@@ -31,6 +31,7 @@ from django.db import router
 from django.http import HttpResponseRedirect
 
 from cms.utils import copy_plugins, permissions, get_language_from_request
+from cms.utils.compat import DJANGO_1_4
 from cms.utils.i18n import get_language_list
 from cms.utils.transaction import wrap_transaction
 
@@ -274,7 +275,10 @@ class PlaceholderAdminMixin(object):
                         args=[plugin.pk])),
             'breadcrumb': plugin.get_breadcrumb(),
         }
-        return HttpResponse(json.dumps(response), content_type='application/json')
+        if DJANGO_1_4:
+            return HttpResponse(json.dumps(response), mimetype='application/json')
+        else:
+            return HttpResponse(json.dumps(response), content_type='application/json')
 
     @method_decorator(require_POST)
     @xframe_options_sameorigin
@@ -344,7 +348,10 @@ class PlaceholderAdminMixin(object):
             )
         self.post_copy_plugins(request, source_placeholder, target_placeholder, plugins)
         json_response = {'plugin_list': reduced_list, 'reload': reload_required}
-        return HttpResponse(json.dumps(json_response), content_type='application/json')
+        if DJANGO_1_4:
+            return HttpResponse(json.dumps(json_response), mimetype='application/json')
+        else:
+            return HttpResponse(json.dumps(json_response), content_type='application/json')
 
     @xframe_options_sameorigin
     def edit_plugin(self, request, plugin_id):
@@ -480,7 +487,10 @@ class PlaceholderAdminMixin(object):
                 x += 1
         self.post_move_plugin(request, source_placeholder, placeholder, plugin)
         json_response = {'reload': requires_reload(PLUGIN_MOVE_ACTION, [plugin])}
-        return HttpResponse(json.dumps(json_response), content_type='application/json')
+        if DJANGO_1_4:
+            return HttpResponse(json.dumps(json_response), mimetype='application/json')
+        else:
+            return HttpResponse(json.dumps(json_response), content_type='application/json')
 
     @xframe_options_sameorigin
     def delete_plugin(self, request, plugin_id):
