@@ -262,6 +262,26 @@ class CMSPlugin(with_metaclass(PluginModelBase, MPTTModel)):
     def copy_plugin(self, target_placeholder, target_language, parent_cache, no_signals=False):
         """
         Copy this plugin and return the new plugin.
+
+        The logic of this method is the following:
+
+         # get a new generic plugin instance
+         # assign the position in the plugin tree
+         # save it to let mptt calculate the tree attributes
+         # then get a copy of the current plugin instance
+         # assign to it the id of the generic plugin instance above;
+           this will effectively change the generic plugin created above
+           into a concrete one
+         # copy the tree related attributes from the generic plugin to
+           the concrete one
+         # save the concrete plugin
+         # trigger the copy relations
+         # return the generic plugin instance
+
+        This copy logic is required because we don't know what the fields of
+        the real plugin are. By getting another instance of it at step 4 and
+        then overwriting its ID at step 5, the ORM will copy the custom
+        fields for us.
         """
         try:
             plugin_instance, cls = self.get_plugin_instance()
@@ -292,9 +312,8 @@ class CMSPlugin(with_metaclass(PluginModelBase, MPTTModel)):
             new_plugin._no_reorder = True
         new_plugin.save()
         if plugin_instance:
-            if plugin_instance.__class__ == CMSPlugin:
-                # get a new instance so references do not get mixed up
-                plugin_instance = CMSPlugin.objects.get(pk=plugin_instance.pk)
+            # get a new instance so references do not get mixed up
+            plugin_instance = plugin_instance.__class__.objects.get(pk=plugin_instance.pk)
             plugin_instance.pk = new_plugin.pk
             plugin_instance.id = new_plugin.pk
             plugin_instance.placeholder = target_placeholder
