@@ -2,7 +2,6 @@
 from __future__ import with_statement
 import itertools
 import warnings
-from cms.utils.urlutils import admin_reverse
 
 from django.conf import settings
 from django.contrib import admin
@@ -35,10 +34,10 @@ from cms.test_utils.fixtures.fakemlng import FakemlngFixtures
 from cms.test_utils.project.fakemlng.models import Translations
 from cms.test_utils.project.objectpermissionsapp.models import UserObjectPermission
 from cms.test_utils.project.placeholderapp.models import (
-    Example1,
-    TwoPlaceholderExample,
     DynamicPlaceholderSlotExample,
-    MultilingualExample1
+    Example1,
+    MultilingualExample1,
+    TwoPlaceholderExample,
 )
 from cms.test_utils.testcases import CMSTestCase
 from cms.test_utils.util.context_managers import (SettingsOverride, UserLoginContext)
@@ -49,6 +48,7 @@ from cms.utils.compat.tests import UnittestCompatMixin
 from cms.utils.conf import get_cms_setting
 from cms.utils.placeholder import PlaceholderNoAction, MLNGPlaceholderActions, get_placeholder_conf
 from cms.utils.plugins import get_placeholders, assign_plugins
+from cms.utils.urlutils import admin_reverse
 
 
 class PlaceholderTestCase(CMSTestCase, UnittestCompatMixin):
